==> modemmanager-qt-5.32.0.zip: modemmanager-qt-5.32.0/src/modemsignal_p.h <==
/*
    Copyright 2014 Lukas Tinkl <ltinkl@redhat.com>
    Copyright 2015 Jan Grulich <jgrulich@redhat.com>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef MODEMMANAGERQT_MODEMSIGNAL_P_H
#define MODEMMANAGERQT_MODEMSIGNAL_P_H

#include "dbus/signalinterface.h"
#include "interface_p.h"
#include "modemsignal.h"

namespace ModemManager
{

class ModemSignalPrivate: public InterfacePrivate
{
public:
    explicit ModemSignalPrivate(const QString &path, ModemSignal *q);
    OrgFreedesktopModemManager1ModemSignalInterface modemSignalIface;

    uint rate;
    QVariantMap cdma;
    QVariantMap evdo;
    QVariantMap gsm;
    QVariantMap umts;
    QVariantMap lte;

    Q_DECLARE_PUBLIC(ModemSignal)
    ModemSignal *q_ptr;
private Q_SLOTS:
    virtual void onPropertiesChanged(const QString &interface, const QVariantMap &properties, const QStringList &invalidatedProps) Q_DECL_OVERRIDE;
};

} // namespace ModemManager

#endif

==> modemmanager-qt-5.45.0.zip: modemmanager-qt-5.45.0/src/modemsignal_p.h <==
/*
    Copyright 2014 Lukas Tinkl <ltinkl@redhat.com>
    Copyright 2015 Jan Grulich <jgrulich@redhat.com>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef MODEMMANAGERQT_MODEMSIGNAL_P_H
#define MODEMMANAGERQT_MODEMSIGNAL_P_H

#include "dbus/signalinterface.h"
#include "interface_p.h"
#include "modemsignal.h"

namespace ModemManager
{

class ModemSignalPrivate: public InterfacePrivate
{
public:
    explicit ModemSignalPrivate(const QString &path, ModemSignal *q);
    OrgFreedesktopModemManager1ModemSignalInterface modemSignalIface;

    uint rate;
    QVariantMap cdma;
    QVariantMap evdo;
    QVariantMap gsm;
    QVariantMap umts;
    QVariantMap lte;

    Q_DECLARE_PUBLIC(ModemSignal)
    ModemSignal *q_ptr;
private Q_SLOTS:
    void onPropertiesChanged(const QString &interface, const QVariantMap &properties, const QStringList &invalidatedProps) Q_DECL_OVERRIDE;
};

} // namespace ModemManager

#endif
